i3(1)
=====
Michael Stapelberg <michael+i3@stapelberg.de>
v3.alpha-bf1, March 2009

== NAME

i3 - an improved dynamic, tiling window manager

== SYNOPSIS

i3 [-c configfile]

== DESCRIPTION

=== INTRODUCTION

i3 was created because wmii, our favorite window manager at the time, didn’t
provide some features we wanted (Xinerama done right, for example), had some
bugs, didn’t progress since quite some time and wasn’t easy to hack at all
(source code comments/documentation completely lacking). Still, we think the
wmii developers and contributors did a great job. Thank you for inspiring us to
create i3.

Please be aware that i3 is primarily targeted at advanced users and developers.

=== TERMINOLOGY

Client::
A client is X11-speak for a window.

Table::
Your workspace is managed using a table. You can move windows around and create new columns
(move a client to the right) or rows (move it to the bottom) implicitly.
+
By "snapping" a client in a specific direction, you increase its colspan/rowspan.

Container::
A container contains a variable number of clients. Each cell of the table is a container.
+
Containers can be used in various modes. The default mode is called "default" and just
resizes each client equally so that it fits.

Workspace::
A workspace is a set of clients (technically speaking, it’s just a table). Other window
managers call this "Virtual Desktops".
+
In i3, each workspace is assigned to a specific virtual screen. By default, screen 1
has workspace 1, screen 2 has workspace 2 and so on… However, when you create a new
workspace (by simply switching to it), it’ll be assigned the screen you are currently
on.

Virtual Screen::
Using Xinerama, you can have an X11 screen spanning multiple real monitors. Furthermore,
you can set them up in cloning mode or with positions (monitor 1 is left of monitor 2).
+
A virtual screen is the result of your Xinerama setup. For example, if you have attached
two real monitors (let’s say your laptop screen and a video projector) and enabled cloning, i3
will use one virtual screen with the size of the smallest screen you have attached (so
that you can see all your windows on each screen all the time).
If you have two monitors attached, one configured to be left of the other, i3 will use
two virtual screens.

== KEYBINDINGS

Here is a short overview of the default keybindings:

j/k/l/;::
Direction keys (left, down, up, right). They are on your homerow (see the mark on your "j" key).

Mod1+<direction>::
Focus window in <direction>.

Mod3+<direction>::
Focus container in <direction>.

Mod1+Shift+<direction>::
Move window to <direction>.

Mod3+Shift+<direction>::
Move container to <direction>.

Mod1+Control+<direction>::
Snap container to <direction>.

Mod1+<number>::
Switch to workspace <number>.

Mod1+Shift+<number>::
Move window to workspace <number>.

Mod1+f::
Toggle fullscreen mode.

Mod1+s::
Enable stacking layout for the current container.

Mod1+d::
Enable default layout for the current container.

Mod1+Shift+q::
Kills the current client.

Mod1+Shift+r::
Restarts i3 in place (without losing any windows, but the layout).

Mod1+Shift+e::
Exits i3.

== FILES

=== ~/.i3/config

When starting, i3 looks for ~/.i3/config and loads the configuration. If ~/.i3/config is not found,
i3 tries /etc/i3/config. You can specify a custom path using the -c option.

At the moment, you can specify only the path to your favorite terminal emulator, the font and keybindings.

At the moment, you have to bind to keycodes (find them out via xev(1)).

.Sample configuration
-------------------------------------------------------------
terminal /usr/bin/urxvt
font -misc-fixed-medium-r-normal--13-120-75-75-C-70-iso10646-1

# Start terminal (Mod1+Enter)
bind Mod1+36 exec /usr/bin/urxvt

# Start dmenu (Mod1+v)
bind Mod1+55 exec /usr/bin/dmenu_run

# Kill current client (Mod1+Shift+q)
bind Mod1+Shift+24 kill

# Beamer on/off
bind Mod1+73 exec /home/michael/toggle_beamer.sh

# Screen locking
bind Mod1+68 exec /usr/bin/i3lock

# Restart i3 inplace (Mod1+Shift+r)
bind Mod1+Shift+27 restart

# Exit i3 (Mod1+Shift+e)
bind Mod1+Shift+26 exit

# Brightness
bind Mod1+97 exec sudo sh -c "echo up > /proc/acpi/ibm/brightness"
bind Mod1+103 exec sudo sh -c "echo down > /proc/acpi/ibm/brightness"

# Fullscreen
bind Mod1+41 f
# Stacking
bind Mod1+43 s
# Default
bind Mod1+26 d

# Focus (Mod1+j/k/l/;)
bind Mod1+44 h
bind Mod1+45 j
bind Mod1+46 k
bind Mod1+47 l

# Focus Container (Mod3+j/k/l/;)
bind Mod3+44 wch
bind Mod3+45 wcj
bind Mod3+46 wck
bind Mod3+47 wcl

# Snap (Mod1+Control+j/k/l/;)
bind Mod1+Control+44 sh
bind Mod1+Control+45 sj
bind Mod1+Control+46 sk
bind Mod1+Control+47 sl

# Move (Mod1+Shift+j/k/l/;)
bind Mod1+Shift+44 mh
bind Mod1+Shift+45 mj
bind Mod1+Shift+46 mk
bind Mod1+Shift+47 ml

# Move Container (Mod3+Shift+j/k/l/;)
bind Mod3+Shift+44 wcmh
bind Mod3+Shift+45 wcmj
bind Mod3+Shift+46 wcmk
bind Mod3+Shift+47 wcml

# Workspaces
bind Mod1+10 1
bind Mod1+11 2
...

# Move to Workspace
bind Mod1+Shift+10 1
bind Mod1+Shift+11 2
...
-------------------------------------------------------------

=== ~/.xsession

This file is where you should configure your locales and start i3. It is run by
your login manager (xdm, slim, gdm, …) as soon as you login.

.Sample xsession
-------------------------------------------------------------
# Disable DPMS turning off the screen
xset dpms force on
xset s off
# Disable bell
xset -b

# Enforce correct locales from the beginning
unset LC_COLLATE
export LC_CTYPE=de_DE.UTF-8
export LC_TIME=de_DE.ISO8859-15
export LC_NUMERIC=de_DE.ISO8859-15
export LC_MONETARY=de_DE.ISO8859-15
export LC_MESSAGES=C
export LC_PAPER=de_DE.ISO8859-15
export LC_NAME=de_DE.ISO8859-15
export LC_ADDRESS=de_DE.ISO8859-15
export LC_TELEPHONE=de_DE.ISO8859-15
export LC_MEASUREMENT=de_DE.ISO8859-15
export LC_IDENTIFICATION=de_DE.ISO8859-15

# Enable core dumps in case something goes wrong
ulimit -c unlimited

# Start i3 and log to ~/.i3/logfile
echo "Starting at $(date)" >> ~/.i3/logfile
exec /usr/bin/i3 >> ~/.i3/logfile
-------------------------------------------------------------

== TODO

There is still lot of work to do. Please check our bugtracker for up-to-date information
about tasks which are still not finished.

== AUTHOR

Michael Stapelberg and contributors
